import java.util.*;
import javax.swing.*;
import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import java.awt.geom.*;

class CompositingFrame2 extends JFrame {

    private DrawPanel drawPanel = new DrawPanel();
    private JComboBox options;
	private BufferedImage source, dest;
    
    class DrawPanel extends JPanel {
   
      public DrawPanel() {
        setBackground(Color.lightGray);
      }
      
      public Dimension getPreferredSize() {
        return new Dimension(200, 150);
      }
    
      public void paintComponent(Graphics g) {
        super.paintComponent(g);
        Graphics2D g2 = (Graphics2D) g;
        
        // Create off-screen image for destination
        dest = new BufferedImage(200, 150, BufferedImage.TYPE_INT_ARGB);
        Graphics2D  destG = dest.createGraphics();
      	
        // Paint destination element (red ellipse)   
        destG.setPaint(Color.red);
        destG.fill(new Ellipse2D.Double(20, 50, 150, 50));
          
        // Create off-screen image for source
        source = new BufferedImage(200, 150, BufferedImage.TYPE_INT_ARGB);
        Graphics2D  sourceG = source.createGraphics();
      	
         // Paint source element (blue rectangle)
        sourceG.setPaint(Color.blue);
        sourceG.fill(new Rectangle2D.Double(75, 20, 50, 110));
        
       // Obtain compositing rule from user
        String rule = (String)options.getSelectedItem();
        if (rule.equals("Src")) destG.setComposite(AlphaComposite.Src);
        if (rule.equals("Dst")) destG.setComposite(AlphaComposite.Dst);
        if (rule.equals("Src-Over-Dst")) destG.setComposite(AlphaComposite.SrcOver);
        if (rule.equals("Dst-Over-Src")) destG.setComposite(AlphaComposite.DstOver);
        if (rule.equals("Src-In-Dst")) destG.setComposite(AlphaComposite.SrcIn);
        if (rule.equals("Dst-In-Src")) destG.setComposite(AlphaComposite.DstIn);
        if (rule.equals("Src-Out-Dst")) destG.setComposite(AlphaComposite.SrcOut);
        if (rule.equals("Dst-Out-Src")) destG.setComposite(AlphaComposite.DstOut);
        if (rule.equals("Src-Atop-Dst")) destG.setComposite(AlphaComposite.SrcAtop);
        if (rule.equals("Dst-Atop-Src")) destG.setComposite(AlphaComposite.DstAtop);
        if (rule.equals("Clear")) destG.setComposite(AlphaComposite.Clear);
        if (rule.equals("Xor")) destG.setComposite(AlphaComposite.Xor);
        
        //Compose source with destination, within destG
        destG.drawImage(source, 0, 0, null);
        // Display on screen
        g2.drawImage(dest, 0, 0, null);
      }
    }

	public CompositingFrame2() {
	 	setTitle("Compositing");
	 	getContentPane().add(drawPanel,BorderLayout.NORTH);
	 	JPanel controlPanel = new JPanel();
	 	getContentPane().add(controlPanel,BorderLayout.SOUTH);
	 	
        options = new JComboBox(
          new String[] {"Src", "Dst", "Src-Over-Dst", "Dst-Over-Src", "Src-In-Dst", "Dst-In-Src", "Src-Out-Dst", 
            "Dst-Out-Src", "Src-Atop-Dst", "Dst-Atop-Src", "Clear", "Xor"});
        options.addItemListener(new ItemListener() {
          public void itemStateChanged(ItemEvent ie) {
            repaint();
          }
        });
        controlPanel.add(options);
	 	
        JButton exitButton = new JButton("Exit");
	 	exitButton.addActionListener(new ActionListener(){
	 	  public void actionPerformed (ActionEvent event) {
            System.exit(0);
          }
	 	});
	 	controlPanel.add(exitButton);
	 	
	 	setDefaultCloseOperation(EXIT_ON_CLOSE);	 	
	 	pack();
	 	setVisible(true);
	 }
	 
}

class Compositing2 {

  public static void main (String[] argv) {	
    CompositingFrame2 cf = new CompositingFrame2();
  }
}
